I added two PRs to prevent global "locks" on the pipeline:
• First one is on the pre-binning mapping, wich has no downsides:
github.com/nf-core/mag/pull/1061. This already shows improvements in the ci: in hybrid profile, runtime went from 21 to 14 min
• Second one is in the seqkit job to get bin sizes, downside is that now there are more (smaller) seqkit jobs:
github.com/nf-core/mag/pull/1062
Both should contribute to better resource usage and (when there are resources available) shorter runtimes.
I noticed both locks when running the benchmarks.